"""
Async Kitsu API Wrapper
~~~~~~~~~~~~~~~~~~~~~~~~

Simple & asynchronus wrapper for the Kitsu API
Written in python

:copyright: (c) 2022-present ShomyKohai
:license: MIT, see LICENSE

"""

__title__ = "askitsu"
__author__ = "ShomyKohai"
__license__ = "MIT"
__copyright__ = "Copyright 2022-present ShomyKohai"
__version__ = "0.5.0"

from .anime import *
from .client import *
from .character import *
from .core import *
from .error import *
from .images import *
from .manga import *
from .users import *
